;*****************************************************************
;       LCDCSTM	(Defines 8 custom LCD characters (5x7 pixels))
;
;	input:	none
;	return:	programs CGRAM with 8 custom characters defined
;	below
;
;	Requires: LCD_Nx16.INC and all registers & subroutines 
;	(WAIT.INC specifically) required by it.
;
;	Executed by:
;
;	CALL	LCDCSTM
;
;	Note: LCD must first be initialized by calling LCDINIT
;	before calling LCDCSTM.
;
;	Custom characters are displayed by:
;
;	MOVLW	0x0?		; ? = addr of character (0-7) 
;	CALL	LCDOUT		; send data to LCD		
;
;	DH MicroSystems, Inc.
;	WWW.DHMICRO.COM
;
;*****************************************************************
LCDCSTM
	BCF	PORTB,RS	; RS line low for control
	CALL	DEL_125		; pause 125uS
	MOVLW	0x40		; set CGRAM base address
	CALL	LCDOUT		; send data to LCD
	BSF	PORTB,RS	; RS line high for data
	CALL	DEL_125		; pause 125uS

;*****************************************************************
;	Custom character data below.  
;	Format your character data in the following manner:
;
;	'00011111'	; top line of character
;	'00011111'
;	'00011111'
;	'00011111'
;	'00011111'
;	'00011111'
;	'00011111'	; bottom line of character
;	'00000000'	; leave all zeros
;
;	A "1" turns a pixel on & a "0" turns a pixel off.
;	The 3 MSBs in each data byte should all be zeros, bits 0
;	through 4 contain data. Define 7 bytes of data for each
;	character plus an 8th byte of all zeros. The 7 bytes 
;	containing 5 data bits define a 5x7 pixel character.
;
;	The pattern above would be a 5x7 solid bar character.
;
;*****************************************************************
CHR_0	MOVLW	b'00010000'
	CALL	LCDOUT
	MOVLW	b'00010000'
	CALL	LCDOUT	
	MOVLW	b'00010000'
	CALL	LCDOUT	
	MOVLW	b'00010000'
	CALL	LCDOUT
	MOVLW	b'00010000'
	CALL	LCDOUT
	MOVLW	b'00010000'
	CALL	LCDOUT	
	MOVLW	b'00010000'
	CALL	LCDOUT	
	MOVLW	b'00010000'	; leave all zeros for 5x7 char.
	CALL	LCDOUT

CHR_1	MOVLW	b'00011000'
	CALL	LCDOUT
	MOVLW	b'00011000'
	CALL	LCDOUT	
	MOVLW	b'00011000'
	CALL	LCDOUT	
	MOVLW	b'00011000'
	CALL	LCDOUT
	MOVLW	b'00011000'
	CALL	LCDOUT
	MOVLW	b'00011000'
	CALL	LCDOUT	
	MOVLW	b'00011000'
	CALL	LCDOUT	
	MOVLW	b'00011000'	; leave all zeros for 5x7 char.
	CALL	LCDOUT

CHR_2	MOVLW	b'00011100'
	CALL	LCDOUT
	MOVLW	b'00011100'
	CALL	LCDOUT	
	MOVLW	b'00011100'
	CALL	LCDOUT	
	MOVLW	b'00011100'
	CALL	LCDOUT
	MOVLW	b'00011100'
	CALL	LCDOUT
	MOVLW	b'00011100'
	CALL	LCDOUT	
	MOVLW	b'00011100'
	CALL	LCDOUT	
	MOVLW	b'00011100'	; leave all zeros for 5x7 char.
	CALL	LCDOUT

CHR_3	MOVLW	b'00011110'
	CALL	LCDOUT
	MOVLW	b'00011110'
	CALL	LCDOUT	
	MOVLW	b'00011110'
	CALL	LCDOUT	
	MOVLW	b'00011110'
	CALL	LCDOUT
	MOVLW	b'00011110'
	CALL	LCDOUT
	MOVLW	b'00011110'
	CALL	LCDOUT	
	MOVLW	b'00011110'
	CALL	LCDOUT	
	MOVLW	b'00011110'	; leave all zeros for 5x7 char.
	CALL	LCDOUT

CHR_4	MOVLW	b'00000000'
	CALL	LCDOUT
	MOVLW	b'00011011'
	CALL	LCDOUT	
	MOVLW	b'00011011'
	CALL	LCDOUT	
	MOVLW	b'00000000'
	CALL	LCDOUT
	MOVLW	b'00010001'
	CALL	LCDOUT
	MOVLW	b'00010001'
	CALL	LCDOUT	
	MOVLW	b'00001110'
	CALL	LCDOUT	
	MOVLW	b'0000000'	; leave all zeros for 5x7 char.
	CALL	LCDOUT

CHR_5	MOVLW	b'00000000'
	CALL	LCDOUT
	MOVLW	b'00000000'
	CALL	LCDOUT	
	MOVLW	b'00000000'
	CALL	LCDOUT	
	MOVLW	b'00000000'
	CALL	LCDOUT
	MOVLW	b'00000000'
	CALL	LCDOUT
	MOVLW	b'00000000'
	CALL	LCDOUT	
	MOVLW	b'00000000'
	CALL	LCDOUT	
	MOVLW	b'00000000'	; leave all zeros for 5x7 char.
	CALL	LCDOUT

CHR_6	MOVLW	b'00000000'
	CALL	LCDOUT
	MOVLW	b'00000000'
	CALL	LCDOUT	
	MOVLW	b'00000000'
	CALL	LCDOUT	
	MOVLW	b'00000000'
	CALL	LCDOUT
	MOVLW	b'00000000'
	CALL	LCDOUT
	MOVLW	b'00000000'
	CALL	LCDOUT	
	MOVLW	b'00000000'
	CALL	LCDOUT	
	MOVLW	b'00000000'	; leave all zeros for 5x7 char.
	CALL	LCDOUT

CHR_7	MOVLW	b'00000000'
	CALL	LCDOUT
	MOVLW	b'00000000'
	CALL	LCDOUT	
	MOVLW	b'00000000'
	CALL	LCDOUT	
	MOVLW	b'00000000'
	CALL	LCDOUT
	MOVLW	b'00000000'
	CALL	LCDOUT
	MOVLW	b'00000000'
	CALL	LCDOUT	
	MOVLW	b'00000000'
	CALL	LCDOUT	
	MOVLW	b'00000000'	; leave all zeros for 5x7 char.
	CALL	LCDOUT
	
	RETLW	0
