;*****************************************************************
;       WAIT (1mS delay subroutine)
;
;       This routine takes the value in W and multiplies it
;	times 1 millisecond to determine total delay time.
;
;	Input: none
;	Output: none
;
;	Requires: DEL1 & DEL2 registers defined.
;
;	Note: Timing in this subroutine makes the assumption that
;	the PIC is running with a 4MHz XTAL or external clock.
;	Timing will obviously be different for different clock
;	speeds.
;
;	Executed by:
;
;	MOVLW	0x??		; duration of delay in mS
;	CALL	WAIT
;
;	DH MicroSystems, Inc.
;	WWW.DHMICRO.COM
;
;*****************************************************************
WAIT	
	MOVWF	DEL1
	MOVF	DEL1,F
	BTFSC	STATUS,Z	; check for zero
	RETLW	0		; if DEL1 = zero just return

DLOOP1	MOVLW	0x64		; initialize inner loop
	MOVWF	DEL2

DLOOP2	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	DECFSZ	DEL2,F		; inner loop complete?
	GOTO	DLOOP2		; no? go again                               
	DECFSZ	DEL1,F		; outer loop complete?
	GOTO	DLOOP1		; no? go again

	RETLW	0