;*****************************************************************
;
;	Filename:	cstm_DEM.ASM
;	Code Rev:	1.0
;	Rev Date:	02/04/04
;	PCB Rev :	R1.0A R18 PCB
;	Author  :	David T. Davis
;
;*****************************************************************
;
;	Oscillator  :	XT
;	Code Protect:	Off
;	Watchdog    :	Off
;	PWR up timer:	Off
;
;*****************************************************************
;
;	Program to demonstrate custom LCD character generating
;	routine on a 2x16 LCD display.
;
;*****************************************************************

	TITLE	"Custom character demo ASM code 1.0"
	LIST	P=PIC16F84, F=INHX8M
	RADIX	HEX
	
;*****************************************************************
;	Register & Bit Definitions For Processor.
;*****************************************************************
	INCLUDE	<P16F84.INC>

;*****************************************************************
;	Register Definitions For Main Routine.
;*****************************************************************
COUNT1	EQU	0x0C
COUNT2	EQU	0x0D

;*****************************************************************
;	Register Definitions For LCD Routines.
;*****************************************************************
LCDBUF	EQU	0x0E		; LCD data buffer
LCDDEL	EQU	0x0F		; LCD 125uS delay register

;*****************************************************************
;	Register Definitions For WAIT Routine.
;*****************************************************************
DEL1	EQU	0x10		; delay register 1
DEL2	EQU	0x11		; delay register 2

;*****************************************************************
;	Initialization routine.
;*****************************************************************
	ORG	0x00

	BANKSEL TRISA
	MOVLW	0x00
	MOVWF	TRISA		; make PORTA all outputs
	MOVLW	0x00
	MOVWF	TRISB		; make PORTB all outputs

	BANKSEL PORTA
	MOVLW	0x00
	MOVWF	PORTA		; init PORTA to all zeros
	MOVLW	0x00
	MOVWF	PORTB		; init PORTB to all zeros

;*****************************************************************
;	Main routine.
;*****************************************************************
MAIN	
	CALL	LCDINIT		; initialize LCD display
	CALL	LCDCSTM		; define custom LCD characters

SPLASH	
	MOVLW	0x00		; LCD column 0
	CALL	LCDL1		; LCD line 1

	MOVLW	0x04		; CGRAM addr of custom character
	CALL	LCDOUT		; send data to LCD
	MOVLW	' '
	CALL	LCDOUT		; send data to LCD
	MOVLW	'D'
	CALL	LCDOUT		; send data to LCD
	MOVLW	'H'
	CALL	LCDOUT		; send data to LCD
	MOVLW	'M'
	CALL	LCDOUT		; send data to LCD
	MOVLW	'i'
	CALL	LCDOUT		; send data to LCD
	MOVLW	'c'
	CALL	LCDOUT		; send data to LCD
	MOVLW	'r'
	CALL	LCDOUT		; send data to LCD
	MOVLW	'o'
	CALL	LCDOUT		; send data to LCD
	MOVLW	' '
	CALL	LCDOUT		; send data to LCD
	MOVLW	'2'
	CALL	LCDOUT		; send data to LCD
	MOVLW	'0'
	CALL	LCDOUT		; send data to LCD
	MOVLW	'0'
	CALL	LCDOUT		; send data to LCD
	MOVLW	'4'
	CALL	LCDOUT		; send data to LCD
	MOVLW	' '
	CALL	LCDOUT		; send data to LCD
	MOVLW	0x04		; CGRAM addr of custom character
	CALL	LCDOUT		; send data to LCD

BAR	CLRF	COUNT1		; init COUNT1
	CLRF	COUNT2		; init COUNT2

BARLOOP	MOVLW	0x64		; setup for 100mS delay
	CALL	WAIT		; pause for 100mS	
	MOVF	COUNT1,W	; LCD current column in COUNT1
	CALL	LCDL2		; LCD line 2
	MOVF	COUNT2,W	; CGRAM addr of custom character
	CALL	LCDOUT		; send data to LCD
	INCF	COUNT2,F	; increment COUNT2 for next char
	MOVLW	0x04
	SUBWF	COUNT2,W
	BTFSC	STATUS,Z	; does COUNT2 = 4?	
	GOTO	BARNEXT		; yes? goto BARNEXT
	GOTO	BARLOOP		; no? go back for the next segment

BARNEXT	MOVLW	0x64		; setup for 100mS delay
	CALL	WAIT		; pause for 100mS
	MOVF	COUNT1,W	; LCD current column in COUNT1
	CALL	LCDL2		; LCD line 2
	MOVLW	0xFF		; ASCII code for solid bar
	CALL	LCDOUT		; send data to LCD
	INCF	COUNT1,F	; increment COUNT1 for next column
	MOVLW	0x10
	SUBWF	COUNT1,W
	BTFSC	STATUS,Z	; does COUNT1 = 17?
	GOTO	BAREND		; yes? goto BAREND
	CLRF	COUNT2		; no? re-init COUNT2
	GOTO	BARLOOP		; and go back for the next segment

BAREND	CALL	PAUSE		; delay for 1S
	CALL	LCDCLR		; clear LCD
	GOTO	SPLASH		; and re-run display routine

PAUSE
	MOVLW	0xFA		; setup for 250mS delay
	CALL	WAIT		; pause for 250mS
	MOVLW	0xFA		; setup for 250mS delay
	CALL	WAIT		; pause for 250mS
	MOVLW	0xFA		; setup for 250mS delay
	CALL	WAIT		; pause for 250mS
	MOVLW	0xFA		; setup for 250mS delay
	CALL	WAIT		; pause for 250mS

	RETLW	0

;*****************************************************************
;	Include files.
;*****************************************************************
	INCLUDE	<LCD_NX16.INC>
	INCLUDE	<LCDCSTM.INC>
	INCLUDE	<WAIT.INC>

;*****************************************************************
;	End of program.
;*****************************************************************

	END
